char *s = N_("Change security settings and access control");
char *s = N_("Desktop Firewall");
